@@ -26,11 +26,11 @@ import yaml
 import numpy
 from collections import defaultdict
 # mine
-from hwrt.HandwrittenData import HandwrittenData  # Needed because of pickle
-import hwrt.preprocessing as preprocessing  # Needed because of pickle
-import hwrt.preprocess_dataset as preprocess_dataset
-import hwrt.features as features
-import hwrt.data_multiplication as data_multiplication
+from HandwrittenData import HandwrittenData  # Needed because of pickle
+import preprocessing  # Needed because of pickle
+import preprocess_dataset
+import features
+import data_multiplication
 
 
 def main(feature_folder, create_learning_curve=False):
